==> zn-plugin-workflow-0.1.5.tgz: package/web/src/exports/WFApply.js <==
var React = require('react');
var CreateInstance = require('../component/CreateInstance.js');
module.exports = React.createClass({
	getInitialState: function (){
		return {
			data: []
		};
	},
	componentDidMount: function (){
		this.__loadWFIndex();
	},
	__parseData: function (data){
		var _root = [],
			_root_ids = {},
			_childs = [];
		data.forEach(function (item){
			if(item.schema_type == 'category'){
				item.children = [];
				_root.push(item);
				_root_ids[item.id] = item;
			}else {
				_childs.push(item);
			}
		});

		_childs.forEach(function (child){
			if(child.zn_tree_pid && _root_ids[child.zn_tree_pid]){
				_root_ids[child.zn_tree_pid].children.push(child);
			}else {

			}
		});

		return _root;
	},
	__loadWFIndex: function (){
		zn.http.post('/zn.plugin.workflow/wfindex/getSessionWFIndex')
			.then(function (data){
				if(data.status == 200){
					this.setState({
						data: this.__parseData(data.result)
					});
				}else {
					zn.notification.error(data.result);
				}
			}.bind(this), function (){
				zn.notification.error('服务器错误');
			});
	},
	__onCreateSuccess: function (instanceId){
		zn.react.session.relativeJump('/znpluginworkflow.WFInstance?instanceId='+instanceId);
	},
	__createInstance: function (index){
		zn.dialog({
			title: '创建【'+ index.zn_title + '】流程实例',
			content: <CreateInstance {...index} onCreateSuccess={this.__onCreateSuccess} />
		});
	},
	render:function(){
		var _self = this;
		return (
			<zn.react.Page className="zn-plugin-workflow-wf-apply" title="流程申请" >
				<ul className="indexs">
					{
						this.state.data.map(function (item){
							return <li className="index">
								<div className="header">
									{item.icon && <i className={"fa zr-padding-5 " + item.icon} />}
									<span>{item.zn_title + (item.children.length?"( "+item.children.length+" )":"")}</span>
								</div>
								<div className="content">
									{
										item.children.map(function (child){
											return <div className="child">
												<div className="info">
													{child.icon && <i className={"fa zr-padding-5 " + child.icon} />}
													<span>{child.zn_title}</span>
												</div>
												<div className="btns">
													<span className="btn">查看单据</span>
													<span className="btn" onClick={()=>_self.__createInstance(child)}><i className="fa fa-plus zr-padding-3" />发起流程</span>
												</div>
											</div>
										})
									}
								</div>
							</li>;
						})
					}
				</ul>
			</zn.react.Page>
		);
	}
});

==> zn-plugin-workflow-0.1.14.tgz: package/web/src/exports/WFApply.js <==
var React = require('react');
var CreateInstance = require('../component/CreateInstance.js');
module.exports = React.createClass({
	getInitialState: function (){
		return {
			data: []
		};
	},
	componentDidMount: function (){
		this.__loadWFIndex();
	},
	__parseData: function (data){
		var _root = [],
			_root_ids = {},
			_childs = [];
		data.forEach(function (item){
			if(item.schema_type == 'category'){
				item.children = [];
				_root.push(item);
				_root_ids[item.id] = item;
			}else {
				_childs.push(item);
			}
		});

		_childs.forEach(function (child){
			if(child.zn_tree_pid && _root_ids[child.zn_tree_pid]){
				_root_ids[child.zn_tree_pid].children.push(child);
			}else {

			}
		});

		return _root;
	},
	__loadWFIndex: function (){
		zn.http.post('/zn.plugin.workflow/wfindex/getSessionWFIndex')
			.then(function (data){
				if(data.status == 200){
					this.setState({
						data: this.__parseData(data.result)
					});
				}else {
					zn.notification.error(data.result);
				}
			}.bind(this), function (){
				zn.notification.error('服务器错误');
			});
	},
	__onCreateSuccess: function (instanceId){
		zn.react.session.relativeJump('/znpluginworkflow.wfinstance?instanceId='+instanceId);
	},
	__createInstance: function (index){
		zn.dialog({
			title: '创建【'+ index.zn_title + '】流程实例',
			content: <CreateInstance {...index} onCreateSuccess={this.__onCreateSuccess} />
		});
	},
	render:function(){
		var _self = this;
		return (
			<zn.react.Page className="zn-plugin-workflow-wf-apply" title="流程申请" >
				<ul className="indexs">
					{
						this.state.data.map(function (item){
							return <li className="index">
								<div className="header">
									{item.icon && <i className={"fa zr-padding-5 " + item.icon} />}
									<span>{item.zn_title + (item.children.length?"( "+item.children.length+" )":"")}</span>
								</div>
								<div className="content">
									{
										item.children.map(function (child){
											return <div className="child">
												<div className="info">
													{child.icon && <i className={"fa zr-padding-5 " + child.icon} />}
													<span>{child.zn_title}</span>
												</div>
												<div className="btns">
													<span className="btn">查看单据</span>
													<span className="btn" onClick={()=>_self.__createInstance(child)}><i className="fa fa-plus zr-padding-3" />发起流程</span>
												</div>
											</div>
										})
									}
								</div>
							</li>;
						})
					}
				</ul>
			</zn.react.Page>
		);
	}
});
